# Security Policy

## Supported Versions

We support only the latest version of Ragna, and we use [SemVer](https://semver.org/)
for versioning. As an early-stage project, we do not guarantee backwards compatibility
for minor versions until the 1.0 release.

You should feel comfortable upgrading if you're using our documented public APIs and pay
attention to `DeprecationWarning`s. Whenever there is a need to break compatibility, it
is announced in the [Changelog](docs/references/changelog.md) and will raise a
`DeprecationWarning` before it's finally really broken.

## Reporting a Vulnerability

If you think you found a vulnerability, please report it at
[ragna/security](https://github.com/Quansight/ragna/security).
